Documentation modules
---------------------
These modules include the documentation for Invenio products.

Included modules:

- `docs-invenio-ils <https://invenioils.docs.cern.ch>`_
    - InvenioILS documentation
- `docs-invneio-rdm <https://inveniordm.docs.cern.ch>`_
    - InvenioRDM documentation
